import pandas as pd
from bs4 import BeautifulSoup
import requests

# this function returns list of world ranking and nationality at beginning of given year
def RankDict(year):
    ranks = {}
    r = requests.get('http://www.pgatour.com/stats/stat.186.' + str(year-1) + '.html')
    soup = BeautifulSoup(r.content, 'html.parser')
    for x in soup.findAll('tbody')[0].findAll('tr'):
        rank = BeautifulSoup(str(x.findAll('td')[0]), 'html.parser').get_text().strip()
        player = BeautifulSoup(str(x.findAll('td', {'class': 'player-name'})), 'html.parser').get_text()
        name = player.split()[1] + ' ' + player.split()[2]
        ranks[name] = rank
    return ranks
# end RankDict

def EuroCodes():
    codes = []
    r = requests.get('http://www.countrycallingcodes.com/iso-country-codes/europe-codes.php')
    soup = BeautifulSoup(r.content, 'html.parser')
    for x in soup.findAll('tr', {'valign': 'top'}):
        code = BeautifulSoup(str(x.findAll('td')[2]), 'html.parser').get_text()
        codes.append(code)
    # add in GBR individually
    codes.append('ENG')
    codes.append('NIR')
    codes.append('SCO')
    codes.append('DEN')
    codes.append('GER')
    codes.append('WAL')
    return codes

# returns the nationality of each player in a dictionary
def NatDict(year):
    nats = {}
    r = requests.get('http://www.pgatour.com/stats/stat.186.' + str(year - 1) + '.html')
    soup = BeautifulSoup(r.content, 'html.parser')
    for x in soup.findAll('tbody')[0].findAll('tr'):
        player = BeautifulSoup(str(x.findAll('td', {'class': 'player-name'})), 'html.parser').get_text()
        name = player.split()[1] + ' ' + player.split()[2]
        nation = BeautifulSoup(str(x.findAll('td')[8]), 'html.parser').get_text().strip()
        nats[name] = nation
    return nats
# end NatDict

def SGP(year):
    putts = {}
    r = requests.get('http://www.pgatour.com/stats/stat.02564.' + str(year-1) + '.html')
    soup = BeautifulSoup(r.content, 'html.parser')
    for x in soup.findAll('tbody')[0].findAll('tr'):
        gain_avg = BeautifulSoup(str(x.findAll('td')[4]), 'html.parser').get_text().strip()
        player = BeautifulSoup(str(x.findAll('td', {'class': 'player-name'})), 'html.parser').get_text()
        name = player.split()[1] + ' ' + player.split()[2]
        putts[name] = gain_avg
    return putts

def nationality(name):
    namelist = name.lower().split()
    dashname = namelist[0] + '-' + namelist[1]
    nation = {}
    r = requests.get('http://www.pgatour.com/players/player.34046.' + dashname + '.html')
    soup = BeautifulSoup(r.content, 'html.parser')
    print(soup.findAll('li', {'class': 'col-title'}))

# returns strokes gained driving for a given year
def SGdrive(year):
    drives = {}
    r = requests.get('http://www.pgatour.com/stats/stat.02567.' + str(year-1) + '.html')
    soup = BeautifulSoup(r.content, 'html.parser')
    for x in soup.findAll('tbody')[0].findAll('tr'):
        gain_avg = BeautifulSoup(str(x.findAll('td')[4]), 'html.parser').get_text().strip()
        player = BeautifulSoup(str(x.findAll('td', {'class': 'player-name'})), 'html.parser').get_text()
        name = player.split()[1] + ' ' + player.split()[2]
        drives[name] = gain_avg
    return drives
# end SGdrive

# this function is going to take a url and a year and return DataFrame of results from each match
# from golfchannel.com
def toPand(url, year):
    rankings = RankDict(year) # generates ranking Dict
    nats = NatDict(year)
    putting = SGP(year) # generates strokes gained at season start
    drives = SGdrive(year)
    matches = []  # empty list
    r = requests.get(url)
    soup = BeautifulSoup(r.content, 'html.parser')
    for match in soup.findAll('tr', {'class': 'matchplay-row left-winner'}):
        new = {}
        winner = BeautifulSoup(str(match.findAll('p', {'class': 'floatLeft oneName'})[0]), 'html.parser')
        loser = BeautifulSoup(str(match.findAll('p', {'class': 'floatright oneName'})[0]), 'html.parser')
        lstwin = winner.get_text().strip().split(', ')
        lstlos = loser.get_text().strip().split(', ')
        new['year'] = year
        new['Winner'] = lstwin[1] + ' ' + lstwin[0]
        new['Loser'] = lstlos[1] + ' ' + lstlos[0]
        new['WinRank'] = rankings.get(new['Winner'])
        new['WinNat'] = nats.get(new['Winner'])
        new['LosRank'] = rankings.get(new['Loser'])
        new['LosNat'] = nats.get(new['Loser'])
        new['WinPutts'] = putting.get(new['Winner'])
        new['LosPutts'] = putting.get(new['Loser'])
        new['WinDrive'] = drives.get(new['Winner'])
        new['LosDrive'] = drives.get(new['Loser'])
        matches.append(new)


    for match in soup.findAll('tr', {'class': 'matchplay-row right-winner'}):
        new = {}
        loser = BeautifulSoup(str(match.findAll('p', {'class': 'floatLeft oneName'})[0]), 'html.parser')
        winner = BeautifulSoup(str(match.findAll('p', {'class': 'floatright oneName'})[0]), 'html.parser')
        lstwin = winner.get_text().strip().split(', ')
        lstlos = loser.get_text().strip().split(', ')
        new['year'] = year
        new['Winner'] = lstwin[1] + ' ' + lstwin[0]
        new['Loser'] = lstlos[1] + ' ' + lstlos[0]
        new['WinRank'] = rankings.get(new['Winner'])
        new['WinNat'] = nats.get(new['Winner'])
        new['LosRank'] = rankings.get(new['Loser'])
        new['LosNat'] = nats.get(new['Loser'])
        new['WinPutts'] = putting.get(new['Winner'])
        new['LosPutts'] = putting.get(new['Loser'])
        new['WinDrive'] = drives.get(new['Winner'])
        new['LosDrive'] = drives.get(new['Loser'])
        matches.append(new)

    return pd.DataFrame(matches)
# end toPand function


