import pandas as pd
from GCtoPandas import EuroCodes

# load in the data into pandas dataframe
data = pd.read_csv("matchplay-2008-2016.csv")

#--------------------------------------------------------------------------------
# DEAL WITH MISSING STROKES GAINED
# if missing strokes gained, just make it the same as opponents so it cancels
data['LosDrive'] = data['LosDrive'].fillna(data['WinDrive'])
data['WinDrive'] = data['WinDrive'].fillna(data['LosDrive'])
data['LosPutts'] = data['LosPutts'].fillna(data['WinPutts'])
data['WinPutts'] = data['WinPutts'].fillna(data['LosPutts'])
# if both were missing, just make them zero
data['LosDrive'] = data['LosDrive'].fillna(0)
data['WinDrive'] = data['WinDrive'].fillna(0)
data['LosPutts'] = data['LosPutts'].fillna(0)
data['WinPutts'] = data['WinPutts'].fillna(0)
#--------------------------------------------------------------------------------

# GENERATE EURO AND AMERICAN VARIABLE
# returns list of european codes
euro = EuroCodes()

data['LosUSA'] = 0
data['WinUSA'] = 0
data.loc[data['LosNat'] == "USA", "LosUSA"] = 1
data.loc[data['WinNat'] == "USA", "WinUSA"] = 1

data['LosEUR'] = 0
data['WinEUR'] = 0
# following two loops indicate if player is a Euro
#--------------------------------
i = 0
for nat in data['LosNat']:
    if euro.count(nat) >= 1:
        data['LosEUR'][i] = 1
    i += 1
#---------------------------------
i = 0
for nat in data['WinNat']:
    if euro.count(nat) >= 1:
        data['WinEUR'][i] = 1
    i += 1
#---------------------------------

# Now update world rank to 64 if it is currently above,
# remember the cutoff to get in was 64, so they must of had a good start to season
data.loc[data['LosRank'] > 64, "LosRank"] = 64
data.loc[data['WinRank'] > 64, "WinRank"] = 64

#--------------------------------------------------------------------------------
# I think I need to make a new dataset where I just enter the data for each match
# from one players perspective, and then include whether he won or lost.
# Going to take turns using the Loser and Winner perspective, so we get both 1's and 0's

# function will return usable data to do analysis on
def clean_matchplay(data):
    cleaning = []
    for i in range(0, len(data)):
        new = {}
        # if odd observation, take losers perspective
        if i % 2 == 1:
            new['player'] = data['Loser'][i]
            new['opponent'] = data['Winner'][i]
            new['rank_diff'] = data['WinRank'][i] - data['LosRank'][i]
            new['putts_diff'] = data['LosPutts'][i] - data['WinPutts'][i]
            new['drive_diff'] = data['LosDrive'][i] - data['WinDrive'][i]
            new['player_nat'] = data['LosNat'][i]
            new['opp_nat'] = data['WinNat'][i]
            new['player_USA'] = data['LosUSA'][i]
            new['opp_USA'] = data['WinUSA'][i]
            new['player_EUR'] = data['LosEUR'][i]
            new['opp_EUR'] = data['WinEUR'][i]
            new['year'] = data['year'][i]
            new['y'] = 0 # we know he lost his match
        else: # take winners perspective
            new['player'] = data['Winner'][i]
            new['opponent'] = data['Loser'][i]
            new['rank_diff'] = data['LosRank'][i] - data['WinRank'][i]
            new['putts_diff'] = data['WinPutts'][i] - data['LosPutts'][i]
            new['drive_diff'] = data['WinDrive'][i] - data['LosDrive'][i]
            new['player_nat'] = data['WinNat'][i]
            new['opp_nat'] = data['LosNat'][i]
            new['player_USA'] = data['WinUSA'][i]
            new['opp_USA'] = data['LosUSA'][i]
            new['player_EUR'] = data['WinEUR'][i]
            new['opp_EUR'] = data['LosEUR'][i]
            new['year'] = data['year'][i]
            new['y'] = 1 # we know he won his match
        # append new to list of dictionaries, cleaning
        cleaning.append(new)
    # return data frame
    return pd.DataFrame(cleaning)

# create clean data and write to csv file
clean = clean_matchplay(data)
order = ['year', 'player', 'player_nat', 'player_USA', 'player_EUR', 'opponent', 'opp_nat', 'opp_USA', 'opp_EUR', 'rank_diff', 'putts_diff', 'drive_diff', 'y']
clean = clean[order]
clean.to_csv('matchplay-2008-2016-clean.csv', sep=',', index=False)



