import numpy as np
import pandas as pd
from numpy import where
from matplotlib.pylab import scatter, show, legend, xlabel, ylabel, title, plot
import matplotlib.pyplot as plt
from sklearn.linear_model import LogisticRegression as logit
import openpyxl

data = np.genfromtxt('matchplay-2008-2016-clean.csv', delimiter=',', skip_header=1,
                     usecols=(3, 4, 7, 8, 9, 10, 11, 12))
pdata = pd.read_csv("matchplay-2008-2016-clean.csv")

# label data X and y
y = data[:, 7]
X = data[:, 0:7]

def strokes_gained_analysis(X, y):
    # get rid of data with all the zeros (when euros didn't have SG stats)
    zeros = where(X[:, 5] == 0)
    X = np.delete(X, zeros, 0)
    y = np.delete(y, zeros, 0)
    # identify wins/losses observations
    win = where(y == 1)
    loss = where(y == 0)
    model = logit(C=100)
    fitted = model.fit(X[:, 5:7], y)
    params = fitted.coef_
    # only need two points to plot straight line
    plot_x = [min(X[:, 5]) - 0.2, max(X[:, 5]) + 0.2]
    plot_x = np.array(plot_x)
    plot_y = (-1/params[0][1]) * (params[0][0] * plot_x + fitted.intercept_[0])
    plot(plot_x, plot_y)
    scatter(X[win, 5], X[win, 6], marker='o', c='g')
    scatter(X[loss, 5], X[loss, 6], marker='x', c='r')
    xlabel('Difference in Strokes Gained Putting')
    ylabel('Difference in Strokes Gained Driving')
    title('Do Strokes Gained Matter?')
    legend(['Decision Boundary', 'Won Match', 'Lost Match'])
    slope = (fitted.intercept_[0] + params[0][0])/params[0][1]
    print('The slope of the line is -' + str(slope) + '.')
    show()

def USAvsEUR(X, y):
    # find matches where EURO played AMERICAN
    us = where(X[:, 0] + X[:, 3] == 2)   # us perspective
    eur = where(X[:, 1] + X[:, 2] == 2)  # euro perspective
    total_matches = 0
    usawins = 0
    for index in us[0]:
        total_matches += 1
        if y[index] == 1: # usa wins match
            usawins += 1
    for index in eur[0]:
        total_matches += 1
        if y[index] == 0: # usa wins match
            usawins += 1
    eurowins = total_matches - usawins
    plt.bar(1, usawins, color='r', align='center', label='USA Wins')
    plt.bar(2, eurowins, color='b', align='center', label='Europe Wins')
    plt.xticks([1, 2], ['USA Wins', 'Europe Wins'])
    plt.ylabel('Wins Head to Head')
    plt.xlabel('Nationality')
    plt.title('USA vs EUROPE')
    plt.show()

# this function takes
def playerstats(panda_data):
    # first create list of all players
    lst = []
    for name in panda_data.player:
        if name not in lst:
            lst.append(name)
    for name in panda_data.opponent:
        if name not in lst:
            lst.append(name)
    # create dictionary with info for each player
    # each player has list that is following:
    # [wins, losses, total matches, percentage win]
    stats = []
    for name in lst:
        new = {}
        total = 0
        wins = 0
        for i in range(0, len(panda_data)):
            if panda_data.player[i] == name:
                total += 1
                if panda_data.y[i] == 1: # he won match
                    wins += 1
            if panda_data.opponent[i] == name:
                total += 1
                if panda_data.y[i] == 0:
                    wins += 1
        new['Name'] = name
        new['Wins'] = wins
        new['Losses'] = total - wins
        new['Total'] = total
        new['Percent'] = float("{0:.2f}".format(wins / total))
        stats.append(new)
        # delete people with less than 5 matches played
    return pd.DataFrame(stats)

def worldrank(pdata):
    pdata['rightguywon'] = 0
    pdata['rank_diff'] = pdata['rank_diff'].fillna(0)
    for i in range(0, len(pdata)):
        if pdata.rank_diff[i] > 0 and pdata.y[i] == 1:
            pdata.rightguywon[i] = 1
        elif pdata.rank_diff[i] < 0 and pdata.y[i] == 0:
            pdata.rightguywon[i] = 1
    pdata['abs_rank'] = pdata['rank_diff'].abs()
    writer1 = pd.ExcelWriter('worldrankhisto.xlsx')
    pdata.to_excel(writer1, 'Sheet1', index=False)
    writer1.save()





strokes_gained_analysis(X, y)
# try non-linearity later
USAvsEUR(X, y)
playerstats(pdata)
writer = pd.ExcelWriter('tableau.xlsx')
playerstats(pdata).to_excel(writer, 'Sheet1', index=False)
writer.save()